#!/usr/bin/env python3

import typing
import asyncio
import threading
from math import nan
from forge.tasks import wait_cancelable
from forge.acquisition.instrument.standard import StandardInstrument
from forge.acquisition.instrument.base import BaseContext, BaseBusInterface, CommunicationsError
from forge.acquisition.instrument.parse import parse_number


class Instrument(StandardInstrument):
    INSTRUMENT_TYPE = "rpicpu"
    MANUFACTURER = "RaspberryPi"
    MODEL = "4B"
    DISPLAY_LETTER = "R"
    TAGS = frozenset({"aerosol", "rpicpu"})

    def __init__(self, context: BaseContext):
        super().__init__(context)

        self.data_Tcpu = self.input("Tcpu")

        self.instrument_report = self.report(
            self.variable_temperature(self.data_Tcpu, "cpu_temperature", code="T",
                                      attributes={'long_name': "CPU internal temperature"}),
        )

    async def run(self) -> typing.NoReturn:
        await self.emit()

        while True:
            await asyncio.sleep(1.0)

            try:
                with open("/sys/class/thermal/thermal_zone0/temp", "r") as f:
                    content = int(f.read())
                self.data_Tcpu(float(content) / 1000.0)
                self.instrument_report()
                self.is_communicating = True
            except (IOError, TypeError, ValueError, OverflowError):
                self.is_communicating = False

            await self.emit()


def main():
    from forge.acquisition.instrument.run import launch
    launch(Instrument)

